# Curvey
Pythonic geometric processing of discrete planar closed curves

- See the [GitHub repo](https://github.com/darikg/curvey) for installation instructions
- See the [tutorials](tutorial/index.md) for a casual introduction
- See the [API documentation](api/index.md) for exhaustive documentation
- See the [bibliography](bibliography.md) for references
